tiled.structures.dataframe.DataFrameMacroStructure
==================================================

.. currentmodule:: tiled.structures.dataframe

.. autoclass:: DataFrameMacroStructure

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataFrameMacroStructure.__init__
      ~DataFrameMacroStructure.from_dask_dataframe
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DataFrameMacroStructure.resizable
   
   